@@ -10,4 +10,4 @@ Copyright (c) 2021 Roi ZHAO
 from .rquote import get_price, get_stock_concepts, get_concept_stks
 from .rquote import get_all_concepts, get_all_industries
 from .rquote import get_cn_stocks_by_amount, get_hk_stocks_hotest80, get_us_stocks_hotest30, get_cn_fund_hotest200, get_cn_future
-from .utils import CommonUtils, WebUtils, reqget
+from .utils import CommonUtils, WebUtils, BasicFactors, DataFormatter, reqget
