@@ -32,7 +32,7 @@ def get_cn_stocks_by_amount(money_min=2e8):
             'Tk2MSZwbj0xJnB6PTEwMDAwJnBvPTEmbnA9MSZ1dD1iZDFkOWRkYjA0MDg5NzAwY2'+
             'Y5YzI3ZjZmNzQyNjI4MSZmbHR0PTImaW52dD0yJmZpZD1mNiZmcz1tOjArdDo2LG0'+
             '6MCt0OjgwLG06MSt0OjIsbToxK3Q6MjMmZmllbGRzPWYxMixmMTQsZjMsZjYsZjIxJl89'
-            ).decode('utf-8')+str(int(time.time()*1e3))
+            ).decode()+str(int(time.time()*1e3))
     )
     if a:
         a = json.loads(a.text.split(
@@ -82,7 +82,7 @@ def get_cn_fund_hotest200():
                                 'Y2tMaXN0WydrMldhekswNk5Rd2xoeVh2J10vTWFya2V0X0NlbnRlci5nZXRIUU5vZ' +
                                 'GVEYXRhU2ltcGxlP3BhZ2U9MSZudW09MTIwJnNvcnQ9YW1vdW50JmFzYz0wJm5vZG' +
                                 'U9ZXRmX2hxX2Z1bmQmJTVCb2JqZWN0JTIwSFRNTERpdkVsZW1lbnQlNUQ9eG00aTA='
-                                ).decode('utf-8')).text
+                                ).decode()).text
     if a:
         fundcands = [i['symbol']
                      for i in json.loads(a.split('k2WazK06NQwlhyXv')[1][3:-2])]
@@ -111,8 +111,8 @@ def get_price(i, sdate='', edate='', freq='day', days=320, fq='hfq',
         a = dd.get(i)
         if a:
             n, d = a
-        logging.debug('loading price from dd {}'.format(i))
-        return i, n, d
+            logging.debug('loading price from dd {}'.format(i))
+            return i, n, d
     logging.debug('fetching price of {}'.format(i))
     qtimg_stock = base64.b64decode('aHR0cDovL3dlYi5pZnpxLmd0aW1nLmNuL2FwcHN0b2' +
                                    'NrL2FwcC9uZXdmcWtsaW5lL2dldD9wYXJhbT17fSx7' +
@@ -126,7 +126,7 @@ def get_price(i, sdate='', edate='', freq='day', days=320, fq='hfq',
     sina_future_d = base64.b64decode('aHR0cHM6Ly9zdG9jazIuZmluYW5jZS5zaW5hLmNv' +
                                      'bS5jbi9mdXR1cmVzL2FwaS9qc29ucC5waHAvdmFy' +
                                      'JTIwX3t9e309L0lubmVyRnV0dXJlc05ld1NlcnZp' +
-                                     'Y2UuZ2V0RGFpbHlLTGluZT9zeW1ib2w9e30mXz17fQ==').decode('utf-8')
+                                     'Y2UuZ2V0RGFpbHlLTGluZT9zeW1ib2w9e30mXz17fQ==').decode()
     # sina_future_d.format('FB0','2020_11_14','FB0','2020_11_14')
 
     if i[:2] == 'BK':
@@ -136,7 +136,7 @@ def get_price(i, sdate='', edate='', freq='day', days=320, fq='hfq',
                                                    'b2NrL2tsaW5lL2dldD9jYj1qUX' +
                                                    'VlcnkxMTI0MDIyNTY2NDQ1ODcz' +
                                                    'NzY2OTcyXzE2MTc4NjQ1NjgxMz' +
-                                                   'Emc2VjaWQ9OTAu').decode('utf-8') + i +
+                                                   'Emc2VjaWQ9OTAu').decode() + i +
                                   '&fields1=f1%2Cf2%2Cf3%2Cf4%2Cf5' +
                                   '&fields2=f51%2Cf52%2Cf53%2Cf54%2Cf55%2Cf56%2Cf57%2Cf58' +
                                   '&klt=101&fqt=0&beg=19900101&end=20220101&_=1',
@@ -153,7 +153,7 @@ def get_price(i, sdate='', edate='', freq='day', days=320, fq='hfq',
             d = pd.DataFrame([i.split(',') for i in a['data']['klines']], columns=[
                              'date', 'open', 'close', 'high', 'low', 'vol', 'money', 'p'])
             d = d.set_index(['date']).astype(float)
-            d.index = pd.DatetimeIndex(d.index)
+            # d.index = pd.DatetimeIndex(d.index)
             return i, name, d
         except Exception as e:
             logging.warning('error fetching {}, err: {}'.format(i, e))
@@ -165,17 +165,22 @@ def get_price(i, sdate='', edate='', freq='day', days=320, fq='hfq',
                 i[2:-4] + '0', '', i[2:-4] + '0', '')).text.split('(')[1][:-2]))
             d.columns = ['date', 'open', 'close', 'high', 'low', 'vol', 'p']
             d = d.set_index(['date']).astype(float)
-            d.index = pd.DatetimeIndex(d.index)
+            # d.index = pd.DatetimeIndex(d.index)
             return i[2:-4], '', d
         except Exception as e:
             logging.warning('error get price {}, err {}'.format(i[2:-4], e))
             return i, 'None', pd.DataFrame([])
+
+    if i[0] in ['0', '1', '3', '5', '6']:
+        i = 'sh'+i if i[0] in ['5', '6'] else 'sz'+i
     if i[:2] in ['sh', 'sz']:
         url = qtimg_stock.format(i, freq, sdate, edate, days, fq)
-    if i[:2] == 'hk':
+    elif i[:2] == 'hk':
         url = qtimg_stock_hk.format(i, freq, sdate, edate, days, fq)
-    if i[:2] == 'us':
+    elif i[:2] == 'us':
         url = qtimg_stock_us.format(i, freq, sdate, edate, days, fq)
+    else:
+        raise ValueError('target market not supported')
     a = reqget(url)
     #a = json.loads(a.text.replace('kline_dayqfq=', ''))['data'][i]
     a = json.loads(a.text)['data'][i]
@@ -216,7 +221,7 @@ def get_stock_concepts(i) -> []:
     Return concept list of a stock, from eastmoney
     '''
     f10url = base64.b64decode('aHR0cDovL2YxMC5lYXN0bW9uZXkuY29tLy9Db3JlQ29uY2V' +
-                              'wdGlvbi9Db3JlQ29uY2VwdGlvbkFqYXg/Y29kZT0=').decode('utf-8')
+                              'wdGlvbi9Db3JlQ29uY2VwdGlvbkFqYXg/Y29kZT0=').decode()
     #drop_cons = ['融资融券', '创业板综', '深股通', '沪股通', '深成500', '长江三角']
     #drop_tails = ['板块', '概念', '0_', '成份', '重仓']
     url = f10url + i
@@ -246,9 +251,9 @@ def get_concept_stks(bkid, dc=None):
         base64.b64decode('aHR0cDovL3B1c2gyLmVhc3Rtb25leS5jb20vYXBpL3F0L2NsaXN0' +
                          'L2dldD9jYj1qUXVlcnkxMTIzMDQwNTcwNTM4NTY5NDcwMTA1XzE2MTgwNDc5OTA2O' +
                          'TAmZmlkPWY2MiZwbz0xJnB6PTUwMCZwbj0xJm5wPTEmZmx0dD0yJmludnQ9MiZmcz' +
-                         '1iJTNB').decode('utf-8') +
+                         '1iJTNB').decode() +
         bkid +
-        '&fields=f12%2Cf14').text
+        '&fields=f3%2Cf6%2Cf12%2Cf14%2Cf21').text
     a = json.loads(
         a.split('jQuery1123040570538569470105_1618047990690(')[1][:-2])['data']['diff']
     logging.debug('get fresh conc {}'.format(bkid))
@@ -257,40 +262,63 @@ def get_concept_stks(bkid, dc=None):
     return a
 
 
-def get_all_industries(orderby='mkt'):
-    a = reqget(
-        base64.b64decode('aHR0cHM6Ly84Ny5wdXNoMi5lYXN0bW9uZXkuY29tL2FwaS9xdC9j'+
-            'bGlzdC9nZXQ/Y2I9alF1ZXJ5MTEyNDAzNzExNzU2NTU3MTk3MTM0NV8xNjI3MDQ3M'+
-            'Tg4NTk5JnBuPTEmcHo9MTAwJnBvPTEmbnA9MSZ1dD1iZDFkOWRkYjA0MDg5NzAwY2'+
-            'Y5YzI3ZjZmNzQyNjI4MSZmbHR0PTImaW52dD0yJmZpZD1mMyZmcz1tOjkwK3Q6Mit'+
-            'mOiE1MCZmaWVsZHM9ZjMsZjEyLGYxNCxmMjAsZjEwNCxmMTA1Jl89').decode('utf-8') +
-        str(int(time.time()*1e3))).text
-    industries = json.loads(
-        a.split('jQuery1124037117565571971345_1627047188599(')[1][:-2])['data']['diff']
-    ind_ids = [i['f12'] for i in industries]
-    if orderby == 'mkt':
-        ind_ids = [i['f12'] for i in sorted(industries,key=lambda k:k['f20'], reverse=True)]
-    elif orderby == 'rise':
-        ind_ids = [i['f12'] for i in sorted(industries,key=lambda k:k['f3'], reverse=True)]
-    logging.debug('get industries {}'.format(len(industries)))
-    return ind_ids
+def east_list_fmt(burl, api_name):
+    '''
+    Return list of list:
+        [sid, name, rise, amount, mkt]
+    '''
+    a = reqget(base64.b64decode(burl).decode() +
+        str(int(time.time()*1e3)))
+    if a:
+        a = a.text
+    else:
+        return
+    a = json.loads(a.split(api_name+'(')[1][:-2])['data']['diff']
+    a = [ [i['f12'],i['f14'], i['f3'], i['f6'], i['f20']] for i in a]
+    return a
 
 
-def get_all_concepts(orderby='mkt'):
-    a = reqget(
-        base64.b64decode('aHR0cHM6Ly8yMi5wdXNoMi5lYXN0bW9uZXkuY29tL2FwaS9xdC9j'+
-            'bGlzdC9nZXQ/Y2I9alF1ZXJ5MTEyNDA3MzI5ODQxOTMwNzY4OTc5XzE2MjcxMDk0N'+
-            'jA2MzMmcG49MSZwej00MDAmcG89MSZucD0xJnV0PWJkMWQ5ZGRiMDQwODk3MDBjZj'+
-            'ljMjdmNmY3NDI2MjgxJmZsdHQ9MiZpbnZ0PTImZmlkPWYzJmZzPW06OTArdDozK2Y'+
-            '6ITUwJmZpZWxkcz1mMyxmMTIsZjE0LGYyMCxmMTA0LGYxMDUmXz0=').decode('utf-8') +
-        str(int(time.time()*1e3))).text
-    concepts = json.loads(
-        a.split('jQuery112407329841930768979_1627109460633(')[1][:-2])['data']['diff']
-    con_ids = [i['f12'] for i in concepts]
-    if orderby == 'mkt':
-        con_ids = [i['f12'] for i in sorted(concepts,key=lambda k:k['f20'], reverse=True)]
-    elif orderby == 'rise':
-        con_ids = [i['f12'] for i in sorted(concepts,key=lambda k:k['f3'], reverse=True)]
-    logging.debug('get concepts {}'.format(len(concepts)))
-    return con_ids
+def get_all_industries():
+    a = east_list_fmt('aHR0cHM6Ly84Ny5wdXNoMi5lYXN0bW9uZXkuY29tL2FwaS9xdC9jbGl'+
+        'zdC9nZXQ/Y2I9alF1ZXJ5MTEyNDAzNzExNzU2NTU3MTk3MTM0NV8xNjI3MDQ3MTg4NTk5'+
+        'JnBuPTEmcHo9MTAwJnBvPTEmbnA9MSZ1dD1iZDFkOWRkYjA0MDg5NzAwY2Y5YzI3ZjZmN'+
+        'zQyNjI4MSZmbHR0PTImaW52dD0yJmZpZD1mMyZmcz1tOjkwK3Q6MitmOiE1MCZmaWVsZH'+
+        'M9ZjMsZjYsZjEyLGYxNCxmMjAsZjEwNCxmMTA1Jl89',
+        'jQuery1124037117565571971345_1627047188599')
+    logging.debug('get industries {}'.format(len(a)))
+    return a
 
+
+def get_all_concepts():
+    a = east_list_fmt('aHR0cHM6Ly8yMi5wdXNoMi5lYXN0bW9uZXkuY29tL2FwaS9xdC9jbGl'+
+        'zdC9nZXQ/Y2I9alF1ZXJ5MTEyNDA3MzI5ODQxOTMwNzY4OTc5XzE2MjcxMDk0NjA2MzMm'+
+        'cG49MSZwej00MDAmcG89MSZucD0xJnV0PWJkMWQ5ZGRiMDQwODk3MDBjZjljMjdmNmY3N'+
+        'DI2MjgxJmZsdHQ9MiZpbnZ0PTImZmlkPWYzJmZzPW06OTArdDozK2Y6ITUwJmZpZWxkcz'+
+        '1mMyxmNixmMTIsZjE0LGYyMCxmMTA0LGYxMDUmXz0='
+        ,'jQuery112407329841930768979_1627109460633')
+    logging.debug('get concepts {}'.format(len(a)))
+    return a
+
+
+def get_bk_stocks(bkid):
+    url = base64.b64decode('aHR0cDovLzgyLnB1c2gyLmVhc3Rtb25leS5jb20vYXBpL3F0L2'+
+        'NsaXN0L2dldD9jYj1qUXVlcnkxMTI0MDQ4Njk5NjMwMDk1MTM3NzE0XzE2Mjc0Nzc0OTU'+
+        'wNjQmcG49MSZwej0yMDAwJnBvPTAmbnA9MSZ1dD1iZDFkOWRkYjA0MDg5NzAwY2Y5YzI3'+
+        'ZjZmNzQyNjI4MSZmbHR0PTImaW52dD0yJmZpZD1mNiZmcz1iOg==').decode()+ \
+        bkid + '+f:!50&fields=f3,f6,f12,f14,f20&_='
+    a = east_list_fmt(base64.b64encode(bytes(url, encoding='utf-8')),
+        'jQuery1124048699630095137714_1627477495064')
+    return a
+
+
+def get_industry_stocks(bkid):
+    url = base64.b64decode('aHR0cHM6Ly82Mi5wdXNoMi5lYXN0bW9uZXkuY29tL2FwaS9xdC'+
+        '9jbGlzdC9nZXQ/Y2I9alF1ZXJ5MTEyNDA4Mzc4MjAwMDc0NDQ0MzA5XzE2Mjc4MjQ2MDM'+
+        '1NjImcG49MSZwej0yMDAwJnBvPTAmbnA9MSZ1dD1iZDFkOWRkYjA0MDg5NzAwY2Y5YzI3'+
+        'ZjZmNzQyNjI4MSZmbHR0PTImaW52dD0yJmZpZD1mNiZmcz1iOg==').decode()+ \
+        bkid + '+f:!50&fields=f3,f6,f12,f14,f20&_='
+    a = east_list_fmt(base64.b64encode(bytes(url, encoding='utf-8')),
+        'jQuery112408378200074444309_1627824603562')
+    return a
+
+    
\ No newline at end of file
